==> apache-camel-1.5.1.10-fuse-src.zip: apache-camel-1.5.1.10-fuse/src/components/camel-cxf/src/test/java/org/apache/camel/component/cxf/CxfRouterTestSupport.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.cxf;

import org.apache.camel.ContextTestSupport;
import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.endpoint.Server;

public abstract class CxfRouterTestSupport extends ContextTestSupport {    

    protected Server server;
    protected Bus bus;


    @Override
    protected void setUp() throws Exception {

        BusFactory.setDefaultBus(null);
        bus = BusFactory.getDefaultBus();
        super.setUp();
        startService();
    }

    protected abstract void startService();
       

    @Override
    protected void tearDown() throws Exception {
        //TODO need to shutdown the server
        super.tearDown();
        //server.stop();
        //bus.shutdown(false);
        BusFactory.setDefaultBus(null);
    }

    
}

==> apache-camel-1.5.2.0-fuse-src.zip: apache-camel-1.5.2.0-fuse/src/components/camel-cxf/src/test/java/org/apache/camel/component/cxf/CxfRouterTestSupport.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.cxf;

import org.apache.camel.CamelContext;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.impl.DefaultCamelContext;
import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.endpoint.Server;
import org.apache.cxf.endpoint.ServerImpl;
import org.apache.cxf.frontend.ClientFactoryBean;
import org.apache.cxf.frontend.ClientProxyFactoryBean;
import org.apache.cxf.frontend.ServerFactoryBean;


public abstract class CxfRouterTestSupport extends ContextTestSupport {    

    protected Server server;
    protected Bus bus;


    @Override
    protected void setUp() throws Exception {

        BusFactory.setDefaultBus(null);
        bus = BusFactory.getDefaultBus();
        super.setUp();
        startService();
    }

    protected abstract void startService();
       

    @Override
    protected void tearDown() throws Exception {
        //TODO need to shutdown the server
        super.tearDown();
        //server.stop();
        //bus.shutdown(false);
        BusFactory.setDefaultBus(null);
    }

    
}
